@echo off
REM
REM
REM
REM  IBM Confidential OCO Source Material
REM
REM  5724-I63, 5724-H88, 5655-N02, 5733-W70 (C) COPYRIGHT International Business Machines Corp. 2005
REM
REM  The source code for this program is not published or otherwise divested
REM  of its trade secrets, irrespective of what has been deposited with the
REM  U.S. Copyright Office.
REM
REM --------------------------------------------------------------------------
REM Description:   Creates the Event Service database for 
REM SQL Server 2000. The SQL Server JDBC driver only supports mixed 
REM authentication mode. Therefore, when the SQL server instance is created,
REM the authentication must be set to "SQL Server and Windows"
REM
REM Usage: cr_event_mssql.bat <userid> <password> [server=<server>]
REM             sauser=<sa_user> [sapassword=<sa_password>]
REM
REM Parameters:
REM    userid      - The SQL Server login id that will own the event tables.
REM                  The id must be created in SQL Server so that a JDBC
REM                  connection can be made to the database. The JDBC drivers
REM                  do not support trusted connections.
REM    password    - The password for the new login id that will be created
REM    server      - The name of the server that contains the SQL Server
REM                  database. Defaults to the local host if not specified.
REM    sa_user
REM    sa_password - The sa password if using mixed authentication mode.
REM                  Specify "sapassword=" if sa user does not have a password.
REM                  If using a trusted connection, do not specify the
REM                  sapassword parameter.
REM
REM Return Codes:  0 for success
REM --------------------------------------------------------------------------

setlocal

%~d0
cd %~p0

set RC=0
set USERID=%~1
set USER_PASSWORD=%~2

if "%USERID%"=="" goto PRINT_USAGE
if "%USER_PASSWORD%"=="" goto PRINT_USAGE

REM The name of the event database. The value is also in the cr_db.mssql script
set DB_NAME=##DB_NAME#
set SERVER=
set SA_USER=
set SA_PASSWORD=
set SA_PASSWORD_SPECIFIED=0

REM pop off the first two required parameters
shift
shift

:PARAM_LOOP
REM No more parameters to process
if "%~1"=="" goto connection
if "%~1"=="server" set SERVER=%~2%&shift&shift&goto PARAM_LOOP
if "%~1"=="sauser" set SA_USER=%~2%&shift&shift&goto PARAM_LOOP
if "%~1"=="sapassword" set SA_PASSWORD=%~2%&shift&shift&set SA_PASSWORD_SPECIFIED=1&goto PARAM_LOOP

REM an invalid option was specified
goto PRINT_USAGE

:CONNECTION
REM Figure out how we're connecting to the database to create the database and user. Is it
REM a trusted connection?

if "%SA_USER%"=="" echo A value is required for parameter sauser.&goto PRINT_USAGE

if "%SA_PASSWORD_SPECIFIED%"=="1" goto SALOGIN
set CONNECTION_ID=-E
goto SERVER

:SALOGIN
set CONNECTION_ID=-U %SA_USER% -P%SA_PASSWORD%

:SERVER
set SERVER_PARAM=-S %SERVER%
if "%SERVER%"=="" set SERVER_PARAM=

:START
REM Create the database
osql -b -d master %SERVER_PARAM% %CONNECTION_ID% -icr_db.mssql
if %ERRORLEVEL% NEQ 0 set RC=%ERRORLEVEL%&goto END

REM configure the database
osql -b -d master %SERVER_PARAM% %CONNECTION_ID% -Q"ALTER DATABASE %DB_NAME% MODIFY FILEGROUP ##EVENT_BASE_NAME# DEFAULT"
if %ERRORLEVEL% NEQ 0 set RC=%ERRORLEVEL%&goto END

osql -b -d master %SERVER_PARAM% %CONNECTION_ID% -Q"exec sp_dboption '%DB_NAME%', 'ANSI warnings', 'TRUE'"
if %ERRORLEVEL% NEQ 0 set RC=%ERRORLEVEL%&goto END

osql -b -d master %SERVER_PARAM% %CONNECTION_ID% -Q"exec sp_dboption '%DB_NAME%', 'trunc. log on chkpt', 'TRUE'"
if %ERRORLEVEL% NEQ 0 set RC=%ERRORLEVEL%&goto END

osql -b -d master %SERVER_PARAM% %CONNECTION_ID% -Q"exec sp_dboption '%DB_NAME%', 'ANSI null default', 'TRUE'"
if %ERRORLEVEL% NEQ 0 set RC=%ERRORLEVEL%&goto END

REM Create the SQL Server login
osql -b -d %DB_NAME% %SERVER_PARAM% %CONNECTION_ID% -Q"exec sp_addlogin @loginame=%USERID%, @passwd='%USER_PASSWORD%', @defdb=%DB_NAME%"
if %ERRORLEVEL% NEQ 0 set RC=%ERRORLEVEL%&goto END

osql -b -d %DB_NAME% %SERVER_PARAM% %CONNECTION_ID% -Q"exec sp_adduser '%USERID%'"
if %ERRORLEVEL% NEQ 0 set RC=%ERRORLEVEL%&goto END

REM grant the user all rights to the event database
osql -b -d %DB_NAME% %SERVER_PARAM% %CONNECTION_ID% -Q"GRANT ALL TO %USERID%"
if %ERRORLEVEL% NEQ 0 set RC=%ERRORLEVEL%&goto END

REM grant the user to access the master database
osql -b -d master %SERVER_PARAM% %CONNECTION_ID% -Q"exec sp_grantdbaccess '%USERID%', '%USERID%'"
if %ERRORLEVEL% NEQ 0 set RC=%ERRORLEVEL%&goto END

REM grant the user to use xa features by adding it to SqlJDBCXAUser role
osql -b -d master %SERVER_PARAM% %CONNECTION_ID% -Q"if (select count(uid) from sysusers where name='SqlJDBCXAUser') = 1 exec sp_addrolemember [SqlJDBCXAUser], '%USERID%'"
if %ERRORLEVEL% NEQ 0 set RC=%ERRORLEVEL%&goto END

REM create the event tables
osql -b -d %DB_NAME% %SERVER_PARAM% -U %USERID% -P%USER_PASSWORD% -icr_tbl.mssql
if %ERRORLEVEL% NEQ 0 set RC=%ERRORLEVEL%&goto END

REM create the catalog tables
osql -b -d %DB_NAME% %SERVER_PARAM% -U %USERID% -P%USER_PASSWORD% -icr_tbl_catalog.mssql
if %ERRORLEVEL% NEQ 0 set RC=%ERRORLEVEL%&goto END

REM populate the meta data
osql -b -d %DB_NAME% %SERVER_PARAM% -U %USERID% -P%USER_PASSWORD% -iins_metadata.mssql
if %ERRORLEVEL% NEQ 0 set RC=%ERRORLEVEL%&goto END

REM Insert the catalog data
osql -b -d %DB_NAME% %SERVER_PARAM% -U %USERID% -P%USER_PASSWORD% -icatalogSeed.mssql
if %ERRORLEVEL% NEQ 0 set RC=%ERRORLEVEL%&goto END

REM Create the stored procedures
osql -b -d %DB_NAME% %SERVER_PARAM% -U %USERID% -P%USER_PASSWORD% -icr_stored_procedure.mssql
if %ERRORLEVEL% NEQ 0 set RC=%ERRORLEVEL%&goto END

goto END

:PRINT_USAGE
REM Print usage messages
set RC=1
echo.
echo Usage: cr_event_mssql.bat ^<userid^> ^<password^> [server=^<server^>]
echo            sauser=^<sa_user^> [sapassword=^<sa_password^>]
echo.
echo Parameters:
echo userid      The SQL Server login id that will own the event tables. The id
echo             must be created in SQL Server so that a JDBC connection can be
echo             made to the database. The JDBC drivers do not support trusted
echo             connections.
echo password    The password for the new login id that will be created
echo server      The name of the server that contains the SQL Server database.
echo             Defaults to the local host if not specified.
echo sa_user     The user id that has privileges to create database and tables.
echo sa_password The sa password if using mixed authentication mode. Specify
echo             sapassword= if sa user does not have a password. If using a
echo             trusted connection, do not specify the sapassword parameter.
echo.
goto END

:END
if defined EVENT_DB_ENV exit %RC% else endlocal&exit /b %RC%