@echo off
REM
REM
REM
REM  IBM Confidential OCO Source Material
REM
REM  5724-I63, 5724-H88, 5655-N02, 5733-W70 (C) COPYRIGHT International Business Machines Corp. 2005
REM
REM  The source code for this program is not published or otherwise divested
REM  of its trade secrets, irrespective of what has been deposited with the
REM  U.S. Copyright Office.
REM
REM --------------------------------------------------------------------------
REM Description:   Removes the Event Service database for SQL Server 2000
REM
REM Usage: rm_event_mssql.bat userid [server=<server>] 
REM            sauser=<sa_user> [sapassword=<sa_password>]
REM
REM Parameters:
REM    userid      - The SQL Server login id that will own the event tables.
REM                  The id must be created in SQL Server so that
REM                  a JDBC connection can be made to the database.
REM                  The JDBC drivers do not support trusted connections.
REM    server      - The name of the server that contains the SQL Server 
REM                  database. Defaults to the local host if not specified.
REM    sa_user     - The sa user that has privileges to create the database, 
REM                  tables.
REM    sa_password - The sa password if using mixed authentication mode.
REM                  Specify "sapassword=" if sa user does not have a password.
REM                  If using a trusted connection, do not specify the
REM                  sapassword parameter.
REM
REM Return Codes:  0 for success
REM --------------------------------------------------------------------------

setlocal

%~d0
cd %~p0

set RC=0

set USERID=%~1
if "%USERID%"=="" goto PRINT_USAGE

set DB_NAME=##DB_NAME#
set SERVER=
set SA_USER=
set SA_PASSWORD=
set SA_PASSWORD_SPECIFIED=0

REM pop off the required parameters
shift

:PARAM_LOOP
REM No more parameters to process
if "%~1"=="" goto connection
if "%~1"=="server" set SERVER=%~2%&shift&shift&goto PARAM_LOOP
if "%~1"=="sauser" set SA_USER=%~2%&shift&shift&goto PARAM_LOOP
if "%~1"=="sapassword" set SA_PASSWORD=%~2%&shift&shift&set SA_PASSWORD_SPECIFIED=1&goto PARAM_LOOP

REM an invalid option was specified
goto PRINT_USAGE

:CONNECTION
REM Figure out how we're connecting to the database to create the database and user. Is it
REM a trusted connection?

REM check for required sa user
if "%SA_USER%"=="" echo A value is required for parameter sauser.&goto PRINT_USAGE


if "%SA_PASSWORD_SPECIFIED%"=="1" goto SALOGIN
set CONNECTION_ID=-E
goto SERVER

:SALOGIN
set CONNECTION_ID=-U %SA_USER% -P%SA_PASSWORD%

:SERVER
set SERVER_PARAM=-S %SERVER%
if "%SERVER%"=="" set SERVER_PARAM=

:START

REM drop the database
osql -b -d master %SERVER_PARAM% %CONNECTION_ID% -Q"drop database %DB_NAME%"
if %ERRORLEVEL% NEQ 0 set RC=%ERRORLEVEL%&goto END

REM Remove the cei user access to master db
osql -b -d master %SERVER_PARAM% %CONNECTION_ID% -Q"exec sp_revokedbaccess '%USERID%'"
REM if %ERRORLEVEL% NEQ 0 set RC=%ERRORLEVEL%&goto END

REM Drop the SQL Server login
osql -b -d master %SERVER_PARAM% %CONNECTION_ID% -Q"exec sp_droplogin @loginame=%USERID%"
if %ERRORLEVEL% NEQ 0 set RC=%ERRORLEVEL%&goto END

goto END

:PRINT_USAGE
REM Print usage messages
set RC=1
echo.
echo Usage: rm_event_mssql.bat userid [server=^<server^>] 
echo           sauser=^<sa_user^> [sapassword=^<sa_password^>]
echo.
echo Parameters:
echo.
echo userid     The SQL Server login id that owns the event tables. The id was
echo            created in SQL Server so that a JDBC connection could be made to
echo            the database. The JDBC drivers do not support trusted connections.
echo server     The name of the server that contains the SQL Server database.
echo            Defaults to the local host if not specified.
echo sa_user    The sa user that has priviledges to create the database and tables.
echo sa_password The sa password if using mixed authentication mode.
echo             Specify sapassword= if sa user does not have a password.
echo             If using a trusted connection, do not specify the sapassword
echo             parameter.
goto END

:END
if defined EVENT_DB_ENV exit %RC% else endlocal&exit /b %RC%